import { jsx, css } from '@emotion/core';
import _pt from 'prop-types';
import { DEFAULT_SIZE, placeholderFontSizes } from './constants.esm.js';
import AvatarSkeleton from './AvatarSkeleton.esm.js';
import { fitText } from './Avatar.helpers.esm.js';

const imageCss = css({
  objectFit: "cover",
  width: "100%",
  height: "100%",
  padding: 0,
  margin: 0
});
const maxFallbackTextWidth = {
  XS: 0.9,
  S: 0.9,
  M: 0.9,
  L: 0.8,
  XL: 0.8,
  XXL: 0.8
};
function Avatar({
  src,
  fallback,
  label,
  size = DEFAULT_SIZE,
  borderColor = null,
  className,
  style
}) {
  const textFitter = fitText({
    maxWidth: maxFallbackTextWidth[size],
    minFontSizeInRem: parseFloat(placeholderFontSizes.XS),
    maxFontSizeInRem: parseFloat(placeholderFontSizes[size])
  });
  return jsx(AvatarSkeleton, {
    size: size,
    borderColor: borderColor,
    className: className,
    style: style,
    title: label
  }, src ? jsx("img", {
    css: imageCss,
    src: src,
    alt: label
  }) : jsx("span", {
    "aria-label": label,
    ref: textFitter
  }, fallback));
}
Avatar.propTypes = {
  src: _pt.string.isRequired,
  label: _pt.string.isRequired,
  fallback: _pt.node,
  size: _pt.oneOf(["XS", "S", "M", "L", "XL", "XXL"]),
  borderColor: _pt.oneOfType([_pt.string, _pt.oneOf([null])]),
  fitTextFallback: _pt.bool,
  className: _pt.string
};

export default Avatar;
//# sourceMappingURL=Avatar.esm.js.map
