import { jsx } from '@emotion/core';
import { DEFAULT_SIZE, borderSizeValues } from './constants.esm.js';
import Avatar from './Avatar.esm.js';

/** @jsx jsx */

const groupBaseCss = _theme => ({
  display: "flex",
  alignItems: "center",
  // Create new stacking context
  zIndex: 0
});

function AvatarsGroup({
  avatars,
  size = DEFAULT_SIZE,
  borderColor = "#fff",
  omittedAvatarsCount = 0,
  omittedAvatarsLabel = `${omittedAvatarsCount} more`,
  className,
  style
}) {
  const commonAvatarProps = {
    size,
    borderColor
  };
  const overlapCss = {
    "&:not(:first-of-type)": {
      marginLeft: `-${borderSizeValues[size] * 2}px`
    }
  };
  return jsx("div", {
    css: groupBaseCss,
    className: className,
    style: style
  }, avatars.map(({
    src,
    label,
    ...avatar
  }, idx, list) => {
    return jsx(Avatar // Using both src and label as key because src might not be unique
    , {
      key: `${src}_${label}_${idx}`,
      src: src,
      label: label,
      ...commonAvatarProps,
      ...avatar,
      css: overlapCss,
      style: {
        zIndex: list.length - idx
      }
    });
  }), omittedAvatarsCount > 0 && jsx(Avatar, {
    src: "" // this is an avatar "lookalike" that indicates how many avatars were left out
    ,
    label: omittedAvatarsLabel,
    css: overlapCss,
    ...commonAvatarProps,
    fallback: `+${omittedAvatarsCount}`
  }));
}

export default AvatarsGroup;
//# sourceMappingURL=AvatarsGroup.esm.js.map
