import { jsx } from '@emotion/core';
import { Fragment } from 'react';
import _pt from 'prop-types';
import { Link } from 'gatsby';

function Breadcrumb({
  children,
  ...rest
}) {
  return jsx("nav", {
    "aria-label": "breadcrumb",
    ...rest
  }, jsx("ol", {
    css: {
      listStyle: `none`,
      margin: 0,
      padding: 0,
      display: `flex`,
      flexWrap: `wrap`
    }
  }, children));
}
Breadcrumb.Item = BreadcrumbItem;

const breadcrumbItemCss = theme => ({
  display: `flex`,
  alignItems: `center`,
  color: theme.colors.purple[50],
  fontFamily: theme.fonts.heading,
  fontSize: theme.fontSizes[3]
});

function BreadcrumbItem({
  to,
  active,
  onClick,
  children,
  ...rest
}) {
  return jsx("li", {
    css: theme => [breadcrumbItemCss(theme), active && {
      color: theme.colors.grey[90]
    }],
    ...rest
  }, to ? jsx(Fragment, null, jsx(Link, {
    to: to,
    onClick: onClick,
    css: {
      textDecoration: `none`,
      color: `inherit`
    }
  }, children), jsx(BreadcrumbArrow, null)) : children);
}

BreadcrumbItem.propTypes = {
  to: _pt.string,
  active: _pt.bool,
  onClick: _pt.func
};
BreadcrumbItem.displayName = `Breadcrumb.Item`;

const breadcrumbArrowCss = theme => ({
  color: theme.colors.grey[60],
  marginRight: theme.space[4],
  marginLeft: theme.space[4],
  verticalAlign: `middle`
});

function BreadcrumbArrow(props) {
  return jsx("svg", {
    width: "6",
    height: "9",
    viewBox: "0 0 6 9",
    fill: "currentColor",
    css: breadcrumbArrowCss,
    ...props
  }, jsx("path", {
    d: "M6 4.5L1.5 8.39711L1.5 0.602886L6 4.5Z"
  }));
}

export { Breadcrumb };
//# sourceMappingURL=Breadcrumb.esm.js.map
