import { jsx } from '@emotion/core';
import { MdCheck, MdClose, MdWarning } from '../../node_modules/react-icons/md/index.esm.esm.js';
import { StructuredLogLevel } from './types.esm.js';
import { FormattedLogMessage } from './FormattedLogMessage.esm.js';
import { BuildLogEntrySkeleton } from './BuildLogEntrySkeleton.esm.js';

/** @jsx jsx */

const baseCss = theme => ({
  [theme.mediaQueries.tablet]: {
    paddingRight: theme.space[10]
  }
});

const messageCss = theme => ({
  // Necessary to set min-width to 0 so that the message does not overflow the row
  minWidth: 0,
  gridColumn: `2 span`,
  [theme.mediaQueries.tablet]: {
    gridColumn: `3 span`
  }
});

function BuildStandardLogEntry({
  level,
  message,
  context,
  location,
  filePath,
  docsUrl,
  errorUrl
}) {
  const displayMessage = context && context.stageLabel ? `${context.stageLabel} failed at ${filePath} ${message?.replace(`${context.stageLabel} failed`, ``)}` : message;
  return jsx(BuildLogEntrySkeleton, {
    icon: jsx(LogEntryStatusIcon, {
      logLevel: level
    }),
    css: baseCss
  }, jsx(FormattedLogMessage, {
    message: displayMessage,
    level: level,
    location: location,
    filePath: filePath,
    docsUrl: docsUrl,
    errorUrl: errorUrl,
    css: messageCss
  }));
}

function LogEntryStatusIcon({
  logLevel
}) {
  const statusVariant = logLevel ? logEntryStatusVariants[logLevel] : null;

  if (!statusVariant) {
    return null;
  }

  return jsx(statusVariant.Icon, {
    "aria-label": statusVariant && statusVariant.label,
    css: statusVariant.styles
  });
}

const logEntryStatusVariants = {
  [StructuredLogLevel.Success]: {
    label: `Completed`,
    Icon: MdCheck,
    styles: theme => ({
      color: theme.colors.grey[40]
    })
  },
  [StructuredLogLevel.Error]: {
    label: `Failed`,
    Icon: MdClose,
    styles: theme => ({
      color: theme.colors.red[60]
    })
  },
  [StructuredLogLevel.Warning]: {
    label: `Warning`,
    Icon: MdWarning,
    styles: theme => ({
      color: theme.colors.yellow[90]
    })
  }
};

export { BuildStandardLogEntry };
//# sourceMappingURL=BuildStandardLogEntry.esm.js.map
