import { jsx } from '@emotion/core';
import { Fragment, forwardRef } from 'react';
import _pt from 'prop-types';
import { MdRefresh } from '../../node_modules/react-icons/md/index.esm.esm.js';
import { BaseButton } from '../BaseButton/BaseButton.esm.js';
import { getButtonCss } from '../../theme/styles/button.esm.js';

function getButtonStyles({
  children,
  size = `L`,
  tone = `BRAND`,
  variant = `PRIMARY`,
  loading,
  leftIcon,
  rightIcon,
  textVariant = `DEFAULT`,
  width
}) {
  return {
    css: getButtonCss({
      size,
      variant,
      tone,
      loading,
      leftIcon,
      rightIcon,
      textVariant,
      width
    }),
    children: leftIcon || rightIcon ? jsx(Fragment, null, leftIcon, children, rightIcon) : children
  };
}
const Button = /*#__PURE__*/forwardRef((props, ref) => {
  const {
    children,
    loading,
    LoadingIcon = MdRefresh,
    size,
    tone,
    variant,
    leftIcon,
    rightIcon,
    textVariant,
    width,
    ...rest
  } = props;
  return jsx(BaseButton, { ...getButtonStyles({
      children,
      loading,
      size,
      tone,
      variant,
      leftIcon,
      rightIcon,
      textVariant,
      width
    }),
    loading: loading,
    LoadingIcon: LoadingIcon,
    ...rest,
    ref: ref
  });
});
Button.propTypes = {
  leftIcon: _pt.node,
  rightIcon: _pt.node
};

export { Button, getButtonStyles };
//# sourceMappingURL=Button.esm.js.map
