import { jsx } from '@emotion/core';
import _pt from 'prop-types';
import { Heading } from '../Heading/Heading.esm.js';

const baseCss = theme => theme.cardStyles.frame;

function Card({
  as: Component = `article`,
  ...rest
}) {
  return jsx(Component, {
    css: baseCss,
    ...rest
  });
}
Card.propTypes = {
  as: _pt.oneOf(["article", "div"])
};
function CardSection({
  as: Component = `div`,
  applyPaddingTop = true,
  applyPaddingBottom = true,
  applyPaddingLeft = true,
  applyPaddingRight = true,
  ...rest
}) {
  const baseSectionCss = theme => [applyPaddingTop && {
    paddingTop: theme.space[7],
    [theme.mediaQueries.desktop]: {
      paddingTop: theme.cardStyles.space.L.paddingTop
    }
  }, applyPaddingBottom && {
    paddingBottom: theme.space[7],
    [theme.mediaQueries.desktop]: {
      paddingBottom: theme.cardStyles.space.L.paddingBottom
    }
  }, applyPaddingLeft && {
    paddingLeft: theme.space[7],
    [theme.mediaQueries.desktop]: {
      paddingLeft: theme.cardStyles.space.L.paddingLeft
    }
  }, applyPaddingRight && {
    paddingRight: theme.space[7],
    [theme.mediaQueries.desktop]: {
      paddingRight: theme.cardStyles.space.L.paddingRight
    }
  }];

  return jsx(Component, {
    css: baseSectionCss,
    ...rest
  });
}
CardSection.propTypes = {
  as: _pt.oneOf([`div`, `p`, `section`, `header`]),
  applyPaddingTop: _pt.bool,
  applyPaddingBottom: _pt.bool,
  applyPaddingLeft: _pt.bool,
  applyPaddingRight: _pt.bool
};

const headerCss = theme => ({
  display: `flex`,
  alignItems: `center`,
  justifyContent: `space-between`,
  fontSize: theme.fontSizes[3],
  lineHeight: 1
});

function CardHeader({
  as = `header`,
  title,
  titleAs = `h3`,
  children,
  ...rest
}) {
  return jsx(CardSection, {
    as: as,
    css: headerCss,
    ...rest
  }, jsx(Heading, {
    as: titleAs,
    fontVariant: "UI"
  }, title), children);
}
CardHeader.propTypes = {
  as: _pt.oneOf(["header", "div"]),
  title: _pt.node.isRequired
};

const footerCss = theme => ({
  background: theme.colors.purple[5],
  display: `flex`,
  alignItems: `center`,
  justifyContent: `space-between`,
  borderBottomLeftRadius: theme.cardStyles.frame.borderRadius,
  borderBottomRightRadius: theme.cardStyles.frame.borderRadius
});

function CardFooter(props) {
  return jsx(CardSection, {
    css: footerCss,
    ...props
  });
}
CardFooter.propTypes = {
  as: _pt.oneOf([`div`, `p`, `section`, `header`]),
  applyPaddingTop: _pt.bool,
  applyPaddingBottom: _pt.bool,
  applyPaddingLeft: _pt.bool,
  applyPaddingRight: _pt.bool
};

const dividerCss = theme => ({
  border: 0,
  borderTop: `1px solid ${theme.colors.standardLine}`,
  margin: 0
});

function CardDivider(props) {
  return jsx("hr", {
    css: dividerCss,
    ...props
  });
}

export { Card, CardDivider, CardFooter, CardHeader, CardSection };
//# sourceMappingURL=Card.esm.js.map
