import { jsx } from '@emotion/core';
import { useState } from 'react';
import _pt from 'prop-types';
import { Button } from '../Button/Button.esm.js';
import copyToClipboard from '../../utils/helpers/copyToClipboard.esm.js';
import { concealedValueContainerCss, concealedValueContentCss, concealedValueInputCss, concealedValueActionsCss, concealedValueButtonCss } from './ConcealedValue.styles.esm.js';

function ConcealedValue({
  value,
  ariaLabel,
  concealed = true,
  delay = 5000
}) {
  const [isCopied, setIsCopied] = useState(false);
  const [isConcealed, setIsConcealed] = useState(concealed);

  const copyHandler = async () => {
    await copyToClipboard(value);
    setIsCopied(true);
    setTimeout(() => {
      setIsCopied(false);
    }, delay);
  };

  const revealHandler = () => {
    setIsConcealed(!isConcealed);
  };

  return jsx("div", {
    css: concealedValueContainerCss
  }, jsx("div", {
    css: concealedValueContentCss
  }, isConcealed ? // classic password dots
  jsx("input", {
    css: concealedValueInputCss,
    type: "text",
    value: "\u2022 \u2022 \u2022 \u2022 \u2022 \u2022",
    "aria-label": `Hidden value of ${ariaLabel}`,
    readOnly: true
  }) : // unmasked value
  jsx("input", {
    css: concealedValueInputCss,
    type: "text",
    value: value,
    "aria-label": ariaLabel,
    readOnly: true
  })), jsx("div", {
    css: concealedValueActionsCss
  }, jsx(Button, {
    size: "S",
    tone: "NEUTRAL",
    variant: "SECONDARY",
    css: concealedValueButtonCss,
    onClick: copyHandler
  }, isCopied ? `Copied` : `Copy`), jsx(Button, {
    size: "S",
    tone: "NEUTRAL",
    variant: "SECONDARY",
    css: concealedValueButtonCss,
    onClick: revealHandler
  }, isConcealed ? `Reveal` : `Conceal`)));
}
ConcealedValue.propTypes = {
  value: _pt.string.isRequired,
  ariaLabel: _pt.string.isRequired,
  delay: _pt.number,
  concealed: _pt.bool
};

export { ConcealedValue };
//# sourceMappingURL=ConcealedValue.esm.js.map
