import { jsx } from '@emotion/core';
import { useRef, useState, useEffect } from 'react';
import _pt from 'prop-types';
import { Button } from '../Button/Button.esm.js';
import copyToClipboard from '../../utils/helpers/copyToClipboard.esm.js';

/** @jsx jsx */

const baseCss = _theme => ({
  "html:not([dir=rtl]) &": {
    borderTopLeftRadius: 0,
    borderBottomLeftRadius: 0
  },
  "html[dir=rtl] &": {
    borderTopRightRadius: 0,
    borderBottomRightRadius: 0
  }
});

function CopyButton({
  onClick,
  content,
  getButtonLabel = copied => copied ? `Copied` : `Copy`,
  getButtonTitle = copied => copied ? `Copied to clipboard` : `Copy to clipboard`,
  delay = 5000,
  children,
  ...props
}) {
  const timeoutRef = useRef(undefined);
  const [copied, setCopied] = useState(false);

  const copyOnClick = e => {
    if (onClick) {
      onClick(e);
    }

    copyToClipboard(content).then(() => {
      setCopied(true);
      timeoutRef.current = window.setTimeout(() => {
        setCopied(false);
      }, delay);
    });
  };

  useEffect(() => () => {
    if (timeoutRef.current) {
      window.clearTimeout(timeoutRef.current);
    }
  }, []);
  return jsx(Button, {
    css: baseCss,
    title: getButtonTitle(copied),
    onClick: copyOnClick,
    size: `S`,
    type: "button",
    variant: `SECONDARY`,
    ...props
  }, getButtonLabel(copied), children);
}

CopyButton.propTypes = {
  getButtonTitle: _pt.func,
  content: _pt.string.isRequired,
  delay: _pt.number,
  onClick: _pt.func,
  getButtonLabel: _pt.func,
  type: _pt.oneOf([`button`, `submit`])
};

export default CopyButton;
//# sourceMappingURL=CopyButton.esm.js.map
