import { jsx } from '@emotion/core';
import { Fragment } from 'react';
import _pt from 'prop-types';
import { MdKeyboardArrowDown } from '../../node_modules/react-icons/md/index.esm.esm.js';
import { Heading } from '../Heading/Heading.esm.js';
import { forwardRefWithAs } from '../../node_modules/@reach/utils/dist/utils.esm.esm.js';
import { DisableReachStyleCheck } from '../../utils/helpers/DisableReachStyleCheck.esm.js';
import { Menu, MenuButton, MenuList, MenuItems, MenuItem, MenuPopover, useMenuButtonContext, MenuLink } from '@reach/menu-button';
import { animated as extendedAnimated, useSpring } from '../../node_modules/react-spring/web.esm.js';
import { dropdownButtonCss, dropdownButtonIconCss, menuItemCss, menuItemToneCss, menuItemIconCss, menuItemIconToneCss, dropdownDividerCss, dropdownHeaderCss, dropdownCss, dropdownSizeCss } from './DropdownMenu.styles.esm.js';

const DropdownMenu = props => jsx(Fragment, null, jsx(DisableReachStyleCheck, {
  reachComponent: "menu-button"
}), jsx(Menu, { ...props
}));
const DropdownMenuButton = props => jsx(MenuButton, { ...props
});
const DropdownMenuButtonStyled = ({
  children,
  ...props
}) => jsx(DropdownMenuButton, { ...props,
  css: dropdownButtonCss
}, children, jsx(MdKeyboardArrowDown, {
  css: dropdownButtonIconCss
}));
const AnimatedMenuList = extendedAnimated(MenuList);
const DropdownMenuItems = ({
  size = `LEGACY`,
  ...rest
}) => {
  const styleProps = useAnimatedMenuItems();

  const finalCss = theme => [dropdownCss(theme), dropdownSizeCss[size](theme)];

  return jsx(AnimatedMenuList, {
    style: styleProps,
    ...rest,
    css: finalCss
  });
};
DropdownMenuItems.propTypes = {
  size: _pt.oneOf([`AUTO`, `MAX_CONTENT`, `LEGACY`])
};
const AnimatedMenuItems = extendedAnimated(MenuItems);
const DropdownMenuItemsLowLevel = ({
  size = `LEGACY`,
  ...rest
}) => {
  const styleProps = useAnimatedMenuItems();

  const finalCss = theme => [dropdownCss(theme), dropdownSizeCss[size](theme)];

  return jsx(AnimatedMenuItems, {
    style: styleProps,
    ...rest,
    css: finalCss
  });
};
DropdownMenuItemsLowLevel.propTypes = {
  size: _pt.oneOf([`AUTO`, `MAX_CONTENT`, `LEGACY`])
};
const DropdownMenuItem = ({
  Icon,
  ...rest
}) => jsx(MenuItem, { ...rest,
  ...getStyledMenuItemProps({
    Icon,
    ...rest
  })
});
DropdownMenuItem.propTypes = {
  Icon: _pt.elementType,
  tone: _pt.oneOf(["DEFAULT", "CRITICAL"])
};
const DropdownMenuLink = forwardRefWithAs(function DropdownMenuLink(props, ref) {
  return jsx(MenuLink, {
    ref: ref,
    ...props,
    ...getStyledMenuItemProps(props)
  });
});

function getStyledMenuItemProps({
  children,
  tone = `DEFAULT`,
  Icon
}) {
  const itemCss = theme => [menuItemCss(theme), menuItemToneCss[tone](theme)];

  const iconCss = theme => [menuItemIconCss(theme), menuItemIconToneCss[tone](theme)];

  return {
    css: itemCss,
    children: Icon ? jsx(Fragment, null, jsx(Icon, {
      css: iconCss,
      style: {
        verticalAlign: `baseline`
      }
    }), children) : children
  };
}

function DropdownMenuPopover(props) {
  return jsx(MenuPopover, { ...props
  });
}
function useDropdownMenuContext() {
  return useMenuButtonContext();
}
function DropdownDivider(props) {
  return jsx("hr", { ...props,
    css: dropdownDividerCss
  });
}
const DropdownHeader = ({
  children,
  ...props
}) => jsx(Heading, { ...props,
  css: dropdownHeaderCss
}, children);

function useAnimatedMenuItems() {
  const {
    isExpanded
  } = useDropdownMenuContext();
  return useSpring({
    opacity: isExpanded ? 1 : 0,
    transform: isExpanded ? "scale(1)" : "scale(0.95)",
    config: {
      tension: 400
    }
  });
}

export { DropdownDivider, DropdownHeader, DropdownMenu, DropdownMenuButton, DropdownMenuButtonStyled, DropdownMenuItem, DropdownMenuItems, DropdownMenuItemsLowLevel, DropdownMenuLink, DropdownMenuPopover, useDropdownMenuContext };
//# sourceMappingURL=DropdownMenu.esm.js.map
