import { jsx } from '@emotion/core';
import _pt from 'prop-types';
import { Button } from '../Button/Button.esm.js';
import { AnchorButton } from '../AnchorButton/AnchorButton.esm.js';
import { LinkButton } from '../LinkButton/LinkButton.esm.js';
import { Link } from '../Link/Link.esm.js';
import Text from '../Text/Text.esm.js';
import { Heading } from '../Heading/Heading.esm.js';

const baseCss = _theme => ({});

const innerCss = _theme => ({
  boxSizing: `content-box`,
  maxWidth: 480,
  display: `flex`,
  flexDirection: `column`,
  alignItems: `center`,
  textAlign: `center`,
  margin: `0 auto`
});

const graphicCss = theme => ({
  maxWidth: 360,
  maxHeight: 120,
  marginBottom: theme.space[7],

  /* Begin icon graphics styles */
  fontSize: theme.fontSizes[10],
  color: theme.colors.grey[40]
  /* End icon graphics styles */

});

const headingCss = theme => ({
  fontSize: theme.fontSizes[4],
  marginTop: 0,
  marginBottom: theme.space[5]
});

const textCss = theme => ({
  marginTop: 0,
  marginBottom: 0,
  fontSize: theme.fontSizes[1],
  "&:not(:last-child)": {
    marginBottom: theme.space[7]
  }
});

const primaryCtaCss = theme => ({
  "&:not(:last-child)": {
    marginBottom: theme.space[5]
  }
});

const secondaryCtaCss = theme => ({
  lineHeight: theme.lineHeights.default,
  fontSize: theme.fontSizes[1]
});

const paddedCss = theme => ({
  borderWidth: 1,
  borderStyle: `solid`,
  borderColor: `transparent`,
  paddingTop: theme.space[10],
  paddingBottom: theme.space[10],
  paddingLeft: theme.space[7],
  paddingRight: theme.space[7]
});

const variantDefaultCss = theme => [paddedCss(theme)];

const variantBorderedCss = theme => [paddedCss(theme), {
  borderColor: theme.colors.grey[30],
  borderRadius: theme.radii[2],
  backgroundColor: theme.colors.white
}];

const variantWithBackgroundCss = theme => [paddedCss(theme), {
  borderColor: theme.colors.grey[5],
  borderRadius: theme.radii[2],
  backgroundColor: theme.colors.grey[5]
}];

const variantCss = {
  DEFAULT: variantDefaultCss,
  BORDERED: variantBorderedCss,
  WITH_BACKGROUND: variantWithBackgroundCss
};
function EmptyState({
  heading,
  headingAs = `h3`,
  text,
  graphic,
  variant = `DEFAULT`,
  primaryAction,
  secondaryAction,
  ...rest
}) {
  return jsx("div", {
    css: theme => [baseCss(), variantCss[variant](theme)],
    ...rest
  }, jsx("div", {
    css: innerCss
  }, graphic && jsx("div", {
    css: graphicCss
  }, graphic), jsx(Heading, {
    as: headingAs,
    css: headingCss,
    variant: "PRIMARY",
    fontVariant: "UI",
    tone: "NEUTRAL"
  }, heading), jsx(Text, {
    size: "M",
    css: textCss
  }, text), primaryAction, secondaryAction));
}
EmptyState.propTypes = {
  heading: _pt.node.isRequired,
  text: _pt.node.isRequired,
  graphic: _pt.node,
  variant: _pt.oneOf([`DEFAULT`, `BORDERED`, `WITH_BACKGROUND`]),
  primaryAction: _pt.node,
  secondaryAction: _pt.node
};
function EmptyStatePrimaryAction(props) {
  const sharedProps = {
    variant: `PRIMARY`,
    size: `L`,
    tone: `BRAND`
  };

  if (isLink(props)) {
    return jsx(LinkButton, {
      css: primaryCtaCss,
      ...props,
      ...sharedProps
    });
  }

  if (isAnchor(props)) {
    return jsx(AnchorButton, {
      css: primaryCtaCss,
      ...props,
      ...sharedProps
    });
  }

  return jsx(Button, {
    css: primaryCtaCss,
    ...props,
    ...sharedProps
  });
}

function isLink(props) {
  return "to" in props;
}

function isAnchor(props) {
  return "href" in props;
}

function EmptyStateSecondaryAction(props) {
  return jsx(Link, {
    css: secondaryCtaCss,
    ...props
  });
}

export { EmptyState, EmptyStatePrimaryAction, EmptyStateSecondaryAction };
//# sourceMappingURL=EmptyState.esm.js.map
