import { jsx } from '@emotion/core';
import { forwardRef, Fragment } from 'react';
import { BaseAnchor } from '../BaseAnchor/BaseAnchor.esm.js';
import _pt from 'prop-types';
import { BaseButton } from '../BaseButton/BaseButton.esm.js';
import { getButtonStyles } from '../Button/Button.esm.js';
import { BaseLink } from '../BaseLink/BaseLink.esm.js';
import { visuallyHiddenCss } from '../../stylesheets/a11y.esm.js';

const baseCss = _theme => ({
  paddingLeft: 0,
  paddingRight: 0,
  paddingTop: 0,
  paddingBottom: 0,
  // override default styles from getButtonStyles
  svg: {
    margin: 0
  }
});

const iconSizeStyles = {
  S: theme => ({
    fontSize: theme.fontSizes[2]
  }),
  M: theme => ({
    fontSize: theme.fontSizes[4]
  }),
  L: theme => ({
    fontSize: theme.fontSizes[5]
  }),
  XL: theme => ({
    fontSize: theme.fontSizes[7]
  })
};

function IconButtonLabel({
  icon,
  children
}) {
  return jsx(Fragment, null, jsx("span", {
    css: visuallyHiddenCss
  }, children), icon);
}

IconButtonLabel.propTypes = {
  icon: _pt.node.isRequired,
  children: _pt.node.isRequired
};
const IconButton = /*#__PURE__*/forwardRef(function IconButton(props, ref) {
  const {
    icon,
    children,
    size,
    tone,
    variant,
    ...rest
  } = props;
  const iconButtonProps = useIconButton({
    icon,
    children,
    size,
    tone,
    variant
  });
  return jsx(BaseButton, { ...iconButtonProps,
    ...rest,
    ref: ref
  });
});
IconButton.propTypes = {
  icon: _pt.node.isRequired,
  children: _pt.node.isRequired
};
const IconAnchorButton = /*#__PURE__*/forwardRef(function IconAnchorButton(props, ref) {
  const {
    icon,
    children,
    size,
    tone,
    variant,
    ...rest
  } = props;
  const iconButtonProps = useIconButton({
    icon,
    children,
    size,
    tone,
    variant
  });
  return jsx(BaseAnchor, { ...iconButtonProps,
    ...rest,
    ref: ref
  });
});
IconAnchorButton.propTypes = {
  icon: _pt.node.isRequired,
  children: _pt.node.isRequired
};
function IconLinkButton(props) {
  const {
    icon,
    children,
    size,
    tone,
    variant,
    ...rest
  } = props;
  const iconButtonProps = useIconButton({
    icon,
    children,
    size,
    tone,
    variant
  });
  return jsx(BaseLink, { ...iconButtonProps,
    ...rest
  });
}
IconLinkButton.propTypes = {
  icon: _pt.node.isRequired,
  children: _pt.node.isRequired
};
function useIconButton({
  icon,
  children,
  size = `L`,
  tone,
  variant
}) {
  const {
    css,
    ...styledButtonProps
  } = getButtonStyles({
    children: jsx(IconButtonLabel, {
      icon: icon
    }, children),
    loading: false,
    size,
    tone,
    variant,
    leftIcon: null,
    rightIcon: null,
    textVariant: `DEFAULT`
  });

  const finalCss = theme => [css(theme), baseCss(), iconSizeStyles[size](theme)];

  return { ...styledButtonProps,
    css: finalCss
  };
}

export { IconAnchorButton, IconButton, IconLinkButton, useIconButton };
//# sourceMappingURL=IconButton.esm.js.map
