import { jsx } from '@emotion/core';
import { BaseAnchor } from '../BaseAnchor/BaseAnchor.esm.js';
import { Link as Link$1 } from 'gatsby';

/** @jsx jsx */

const baseCss = theme => ({
  alignItems: `center`,
  color: theme.colors.purple[60],
  display: `inline-flex`
});

const variantsCss = {
  DEFAULT: theme => ({
    textDecoration: `underline`,
    ":focus, :hover": {
      color: theme.colors.purple[60],
      textDecoration: `underline`
    }
  }),
  SIMPLE: theme => ({
    textDecoration: `none`,
    ":focus, :hover": {
      color: theme.colors.purple[40],
      textDecoration: `underline`
    }
  })
};
function Link({
  variant = `DEFAULT`,
  ...rest
}) {
  const commonProps = {
    css: theme => [baseCss(theme), variantsCss[variant](theme)]
  };

  if (isGatsbyLink(rest)) {
    // GatsbyLink does not support target attribute
    return jsx(Link$1, { ...commonProps,
      ...rest,
      target: undefined
    });
  }

  return jsx(BaseAnchor, { ...commonProps,
    ...rest
  });
}
/**
 * An awesome tidbit from React TypeScript Cheatsheet
 * https://github.com/typescript-cheatsheets/react-typescript-cheatsheet/blob/master/ADVANCED.md#typing-a-component-that-accepts-different-props
 */

function isGatsbyLink(props) {
  return "to" in props;
}

export { Link };
//# sourceMappingURL=Link.esm.js.map
