import { keyframes, jsx } from '@emotion/core';
import { Fragment, cloneElement } from 'react';
import _pt from 'prop-types';
import colors from '../../theme/colors.esm.js';
import { DisableReachStyleCheck } from '../../utils/helpers/DisableReachStyleCheck.esm.js';
import { DialogOverlay } from '@reach/dialog';
import { hexToRGBA } from '../../utils/helpers/hexToRgb.esm.js';

const buildFadeIn = color => keyframes`
    0% {
       background-color: transparent;
     }
   
     100% {
       background-color: ${color};
     }
   `;

const fadeMap = {
  info: buildFadeIn(hexToRGBA(colors.purple[50], 0.75)),
  success: buildFadeIn(hexToRGBA(colors.green[50], 0.75)),
  warn: buildFadeIn(hexToRGBA(colors.orange[50], 0.75)),
  error: buildFadeIn(hexToRGBA(colors.red[50], 0.75)),
  neutral: buildFadeIn(hexToRGBA(colors.grey[50], 0.75))
};

const overlayCss = theme => ({
  background: `hsla(0, 0%, 0%, 0.33)`,
  position: `fixed`,
  top: 0,
  right: 0,
  bottom: 0,
  left: 0,
  overflowX: `hidden`,
  overflowY: `auto`,
  zIndex: theme.zIndices.modals
});

const Modal = ({
  type = "info",
  initialFocusRef,
  isOpen,
  onDismiss,
  children,
  ...props
}) => {
  return jsx(Fragment, null, jsx(DisableReachStyleCheck, {
    reachComponent: "dialog"
  }), jsx(DialogOverlay, {
    initialFocusRef: initialFocusRef,
    isOpen: isOpen,
    onDismiss: onDismiss,
    css: theme => [overlayCss(theme), {
      animation: `${fadeMap[type]} 0.5s ease forwards`
    }]
  }, /*#__PURE__*/cloneElement(children, props)));
};
Modal.propTypes = {
  type: _pt.oneOf(["success", "info", "warn", "error", "neutral"])
};

export { Modal };
//# sourceMappingURL=Modal.esm.js.map
