import { jsx } from '@emotion/core';
import _pt from 'prop-types';
import { warn } from '../../utils/maintenance/warn.esm.js';
import { animated as extendedAnimated, useSpring } from '../../node_modules/react-spring/web.esm.js';
import { ModalContent } from './ModalContent.esm.js';

const baseCss = theme => ({
  background: theme.colors.white,
  height: `100vh`,
  bottom: 0,
  top: 0,
  position: "fixed",
  overflowY: "auto"
});

const DEFAULT_MAX_WIDTH = `432px`;
const WIDE_MAX_WIDTH = `36rem`;
const sizesStyles = {
  DEFAULT: _theme => ({
    width: `100vw`,
    [`@media (min-width: ${DEFAULT_MAX_WIDTH})`]: {
      maxWidth: DEFAULT_MAX_WIDTH
    }
  }),
  WIDE: _theme => ({
    width: `100vw`,
    [`@media (min-width: ${WIDE_MAX_WIDTH})`]: {
      maxWidth: WIDE_MAX_WIDTH
    }
  })
};
const AnimatedModalContent = extendedAnimated(ModalContent);
const springConfig = {
  right: {
    from: {
      transform: "translate3d(100%,0,0)"
    }
  },
  left: {
    from: {
      transform: "translate3d(-100%,0,0)"
    }
  }
};
const ModalPanel = ({
  maxWidth,
  position = `right`,
  size = `DEFAULT`,
  ...props
}) => {
  const styleProps = useSpring({
    to: {
      transform: "translate3d(0,0,0)"
    },
    config: {
      tension: 400,
      mass: 1,
      friction: 40
    },
    ...springConfig[position]
  });

  if (maxWidth) {
    warn(`"maxWidth" prop has been deprecated in favour of "size" (set to "DEFAULT" if not passed)`);
  }

  return jsx(AnimatedModalContent, {
    style: styleProps,
    css: theme => [baseCss(theme), maxWidth ? {
      maxWidth
    } : sizesStyles[size](theme), position === `right` ? {
      right: 0
    } : {
      left: 0
    }],
    ...props
  });
};
ModalPanel.propTypes = {
  position: _pt.oneOf(["left", "right"]),
  size: _pt.oneOf(["DEFAULT", "WIDE"]),
  maxWidth: _pt.string
};

export { ModalPanel };
//# sourceMappingURL=ModalPanel.esm.js.map
