import { jsx } from '@emotion/core';
import { Fragment } from 'react';
import _pt from 'prop-types';
import { Heading } from '../Heading/Heading.esm.js';
import { Modal } from './Modal.esm.js';
import { ModalPanel } from './ModalPanel.esm.js';
import { StyledModalCloseButton } from './StyledModal.esm.js';
import { StickyObserver } from '../StickyObserver/StickyObserver.esm.js';

function StyledPanel({
  children
}) {
  return jsx(Fragment, null, children);
}
StyledPanel.propTypes = {
  children: _pt.node.isRequired
};

const headerContainerCss = theme => ({
  backgroundColor: theme.colors.white,
  borderBottom: `1px solid ${theme.colors.grey[20]}`
});

const headerCss = theme => ({
  display: `flex`,
  alignItems: `center`,
  justifyContent: `space-between`,
  paddingTop: theme.space[7],
  paddingRight: theme.space[7],
  paddingBottom: theme.space[7],
  paddingLeft: theme.space[7]
});

const headingCss = theme => ({
  fontSize: theme.fontSizes[4]
});

function StyledPanelHeader({
  children,
  onCloseButtonClick,
  closeButtonLabel = `Close panel`
}) {
  return jsx(StickyObserver, {
    lipShadowPosition: "bottom",
    css: headerContainerCss
  }, jsx("div", {
    css: headerCss
  }, jsx(Heading, {
    variant: "PRIMARY",
    fontVariant: "UI",
    css: headingCss
  }, children), jsx(StyledPanelCloseButton, {
    onClick: onCloseButtonClick,
    "aria-label": closeButtonLabel
  })));
}
StyledPanelHeader.propTypes = {
  children: _pt.node.isRequired,
  onCloseButtonClick: _pt.func,
  closeButtonLabel: _pt.string
};
function StyledPanelCloseButton(props) {
  return jsx(StyledModalCloseButton, { ...props
  });
}

const bodySectionCss = theme => ({
  backgroundColor: theme.colors.white,
  paddingTop: theme.space[5],
  paddingRight: theme.space[7],
  paddingBottom: theme.space[7],
  paddingLeft: theme.space[7]
});

function StyledPanelBodySection(props) {
  return jsx("div", {
    css: bodySectionCss,
    ...props
  });
}

const actionsContainerCss = theme => ({
  width: `100%`,
  backgroundColor: theme.colors.white,
  borderTop: `1px solid ${theme.colors.grey[20]}`
});

const actionsCss = theme => ({
  display: `flex`,
  alignItems: `center`,
  justifyContent: `space-between`,
  paddingTop: theme.space[7],
  paddingRight: theme.space[7],
  paddingBottom: theme.space[7],
  paddingLeft: theme.space[7]
});

function StyledPanelActions({
  children
}) {
  return jsx(StickyObserver, {
    lipShadowPosition: "top",
    css: actionsContainerCss
  }, jsx("div", {
    css: actionsCss
  }, children));
}
StyledPanelActions.propTypes = {
  children: _pt.node.isRequired
};
function StyledPanelBoilerplate({
  isOpen,
  "aria-label": ariaLabel,
  onClose,
  header,
  children,
  actions
}) {
  return jsx(Modal, {
    "aria-label": ariaLabel,
    isOpen: isOpen,
    onDismiss: onClose,
    type: "neutral",
    css: {
      display: `flex`,
      flexDirection: `column`
    }
  }, jsx(ModalPanel, null, jsx(StyledPanel, null, header ? jsx(StyledPanelHeader, {
    onCloseButtonClick: onClose
  }, header) : null, children, actions ? jsx(StyledPanelActions, null, actions) : null)));
}
StyledPanelBoilerplate.propTypes = {
  isOpen: _pt.bool,
  "aria-label": _pt.string.isRequired,
  onClose: _pt.func.isRequired,
  header: _pt.node,
  children: _pt.node,
  actions: _pt.node
};

export { StyledPanel, StyledPanelActions, StyledPanelBodySection, StyledPanelBoilerplate, StyledPanelCloseButton, StyledPanelHeader };
//# sourceMappingURL=StyledPanel.esm.js.map
