import { jsx } from '@emotion/core';
import _pt from 'prop-types';

const baseCss = theme => ({
  display: `inline-block`,
  fontFamily: theme.fonts.sans,
  fontSize: theme.fontSizes[0],
  lineHeight: theme.lineHeights.solid,
  fontWeight: theme.fontWeights.semiBold,
  backgroundColor: theme.colors.grey[20],
  color: theme.colors.grey[60],
  paddingLeft: `calc(3 * ${theme.space[1]})`,
  paddingRight: `calc(3 * ${theme.space[1]})`,
  paddingTop: theme.space[1],
  paddingBottom: theme.space[1],
  borderRadius: theme.radii[5]
});

const borderStyle = _ => ({
  borderWidth: `1px`,
  borderStyle: `solid`
});

const colorsCss = {
  SUCCESS: theme => ({
    backgroundColor: theme.tones.SUCCESS.lighter,
    color: theme.tones.SUCCESS.superDark
  }),
  DANGER: theme => ({
    backgroundColor: theme.tones.DANGER.lighter,
    color: theme.tones.DANGER.superDark
  }),
  WARNING: theme => ({
    backgroundColor: theme.tones.WARNING.light,
    color: theme.tones.WARNING.textInverted
  }),
  NEUTRAL: theme => ({
    backgroundColor: theme.tones.NEUTRAL.light,
    color: theme.tones.NEUTRAL.dark
  })
};
const borderCss = {
  SUCCESS: theme => ({
    borderColor: theme.tones.SUCCESS.darker
  }),
  DANGER: theme => ({
    borderColor: theme.tones.DANGER.darker
  }),
  WARNING: theme => ({
    borderColor: theme.tones.WARNING.darker
  }),
  NEUTRAL: theme => ({
    borderColor: theme.tones.NEUTRAL.darker
  })
};
function NumberBadge({
  tone = `NEUTRAL`,
  withBorder = false,
  ...rest
}) {
  return jsx("span", {
    css: theme => [baseCss(theme), colorsCss[tone](theme), withBorder && [borderStyle(), borderCss[tone](theme)]],
    ...rest
  });
}
NumberBadge.propTypes = {
  tone: _pt.oneOf([`SUCCESS`, `DANGER`, `WARNING`, `NEUTRAL`]),
  withBorder: _pt.bool
};

export { NumberBadge };
//# sourceMappingURL=NumberBadge.esm.js.map
