import { jsx } from '@emotion/core';
import { useContext, createContext } from 'react';
import _pt from 'prop-types';

const PlaceholderContext = /*#__PURE__*/createContext({
  animation: ""
});
const Placeholder = ({
  children,
  space = 3,
  animation = "",
  ...props
}) => {
  return jsx(PlaceholderContext.Provider, {
    value: {
      animation
    }
  }, jsx("div", {
    css: theme => ({
      display: "grid",
      gap: theme.space[space]
    }),
    ...props
  }, children));
};
Placeholder.propTypes = {
  animation: _pt.string,
  css: _pt.any
};

const placeholderLineCss = theme => ({
  background: theme.colors.grey[30],
  height: theme.fontSizes[3]
});

const PlaceholderBox = ({
  height = "14px",
  width = "100%",
  radii = 2,
  ...props
}) => {
  const {
    animation
  } = useContext(PlaceholderContext);
  return jsx("div", {
    css: theme => [placeholderLineCss(theme), {
      width,
      height,
      borderRadius: theme.radii[radii],
      animation
    }],
    ...props
  });
};
PlaceholderBox.propTypes = {
  width: _pt.string,
  height: _pt.string,
  noSpace: _pt.bool,
  radii: _pt.number,
  css: _pt.any
};

export { Placeholder, PlaceholderBox };
//# sourceMappingURL=Placeholder.esm.js.map
