import { jsx } from '@emotion/core';
import { Badge } from '../Badge/Badge.esm.js';
import FreePlanIcon from '../icons/FreePlanIcon.esm.js';
import ProfessionalPlanIcon from '../icons/ProfessionalPlanIcon.esm.js';
import BusinessPlanIcon from '../icons/BusinessPlanIcon.esm.js';
import EnterprisePlanIcon from '../icons/EnterprisePlanIcon.esm.js';
import IndividualPlanIcon from '../icons/IndividualPlanIcon.esm.js';
import TeamPlanIcon from '../icons/TeamPlanIcon.esm.js';

/** @jsx jsx */

const baseCss = _theme => ({
  fontWeight: 500
});

const planTypeFreeCss = theme => ({
  borderColor: theme.colors.blue[10],
  backgroundColor: theme.colors.blue[10],
  color: theme.colors.blue[80]
});

const planTypeIndividualCss = theme => ({
  borderColor: theme.colors.orange[10],
  backgroundColor: theme.colors.orange[10],
  color: theme.colors.red[70]
});

const planTypeTeamCss = theme => ({
  borderColor: theme.colors.magenta[10],
  backgroundColor: theme.colors.magenta[10],
  color: theme.colors.magenta[70]
});

const planTypeEnterpriseCss = theme => ({
  borderColor: theme.colors.purple[80],
  backgroundColor: theme.colors.purple[80],
  color: theme.colors.white
});

const planTypeProfessionalCss = theme => ({
  borderColor: theme.colors.blue[10],
  backgroundColor: theme.colors.blue[10],
  color: theme.colors.blue[90]
});

const planTypeBusinessCss = theme => ({
  borderColor: theme.colors.purple[10],
  backgroundColor: theme.colors.purple[10],
  color: theme.colors.purple[70]
});

const trialingCss = theme => ({
  borderColor: theme.colors.green[10],
  backgroundColor: theme.colors.green[10],
  color: theme.colors.green[90]
});

const planTypeCss = {
  FREE: planTypeFreeCss,
  INDIVIDUAL: planTypeIndividualCss,
  TEAM: planTypeTeamCss,
  ENTERPRISE: planTypeEnterpriseCss,
  PROFESSIONAL: planTypeProfessionalCss,
  BUSINESS: planTypeBusinessCss
};
const planTypeIcons = {
  FREE: FreePlanIcon,
  INDIVIDUAL: IndividualPlanIcon,
  TEAM: TeamPlanIcon,
  ENTERPRISE: EnterprisePlanIcon,
  PROFESSIONAL: ProfessionalPlanIcon,
  BUSINESS: BusinessPlanIcon
};
function PlanIndicator({
  planType,
  isTrialling = false,
  children,
  "aria-label": ariaLabel
}) {
  const Icon = planTypeIcons[planType];
  return jsx(Badge, {
    size: "M",
    textVariant: "DEFAULT",
    Icon: isTrialling ? undefined : Icon,
    "aria-label": ariaLabel,
    css: theme => [baseCss(), isTrialling ? trialingCss(theme) : planTypeCss[planType](theme)]
  }, children);
}

export { PlanIndicator };
//# sourceMappingURL=PlanIndicator.esm.js.map
