import { useState, useLayoutEffect, useRef } from 'react';
import _pt from 'prop-types';
import { createPortal } from 'react-dom';

const useDOMNode = (tag, isUnique) => {
  const domElRef = useRef(undefined);
  useLayoutEffect(() => {
    if (tag) {
      if (isUnique) {
        domElRef.current = document.querySelector(tag);

        if (!domElRef.current) {
          domElRef.current = document.createElement(tag);
          document.body.appendChild(domElRef.current);
        }
      } else {
        domElRef.current = document.createElement(tag);
      }

      return () => {
        if (isUnique) {
          const domNodeToRemove = document.querySelector(tag);
          domNodeToRemove && document.body.removeChild(domNodeToRemove);
        }
      };
    }
  }, [tag, isUnique]);
  return domElRef;
};

const Portal = ({
  children,
  tag = `gatsby-portal`,
  target
}) => {
  const portalNodeRef = useDOMNode(tag);
  const portalRootRef = useDOMNode(target, true);
  const [hasInitialized, setHasInitialized] = useState(false);
  useLayoutEffect(() => {
    if (portalNodeRef.current) {
      const hostNode = portalRootRef.current || document.body;
      hostNode.appendChild(portalNodeRef.current);
      setHasInitialized(true);
      return () => hostNode.removeChild(portalNodeRef.current);
    }
  }, [tag, target]);
  return hasInitialized && portalNodeRef.current ? /*#__PURE__*/createPortal(children, portalNodeRef.current) : null;
};

Portal.propTypes = {
  tag: _pt.string,
  target: _pt.string
};

export default Portal;
//# sourceMappingURL=index.esm.js.map
