import { jsx } from '@emotion/core';
import _pt from 'prop-types';
import { visuallyHiddenCss } from '../../stylesheets/a11y.esm.js';

const defaultGetProgressColor = (theme, progression) => {
  if (progression < 33) {
    return theme.colors.red[50];
  }

  if (progression < 66) {
    return theme.colors.orange[50];
  }

  return theme.colors.green[50];
};

const sharedPseudoCss = (theme, progression, getProgressColor) => ({
  content: "''",
  width: `${progression}%`,
  height: "6px",
  position: "absolute",
  backgroundColor: getProgressColor(theme, progression),
  borderRadius: theme.radii[5]
});

const progressCss = (theme, progression, getProgressColor) => ({
  display: "block",
  width: "100%",
  height: "6px",
  borderRadius: theme.radii[5],
  position: "relative",
  background: theme.colors.grey[20],
  "&:after": sharedPseudoCss(theme, progression, getProgressColor)
});

const secondProgressCss = (theme, progression, getProgressColor) => ({
  "&:before": sharedPseudoCss(theme, progression, getProgressColor)
});

const ProgressBar = ({
  max,
  min = 0,
  value,
  secondValue,
  getProgressColor = defaultGetProgressColor,
  getSecondProgressColor = defaultGetProgressColor,
  height = 6,
  ...props
}) => {
  const normalizedValue = value > max ? max : value < min ? min : value;
  const progression = normalizedValue / max * 100;
  let normalizedSecondValue = null;
  let secondProgression = null;

  if (secondValue) {
    normalizedSecondValue = secondValue > max ? max : secondValue < min ? min : secondValue;
    secondProgression = normalizedSecondValue / max * 100;
  }

  return jsx("div", {
    "aria-describedby": props["aria-describedby"],
    role: "progressbar",
    "aria-valuenow": normalizedValue,
    "aria-valuemin": min,
    "aria-valuemax": max,
    css: theme => [progressCss(theme, progression, getProgressColor), secondProgression && secondProgressCss(theme, secondProgression, getSecondProgressColor), height && {
      height: `${height}px`,
      "&:before, &:after": {
        height: `${height}px`
      }
    }]
  }, jsx("span", {
    css: visuallyHiddenCss
  }, `${normalizedValue}/${max}${secondProgression ? `, ${normalizedSecondValue}/${max}` : ``}`));
};
ProgressBar.propTypes = {
  max: _pt.number.isRequired,
  min: _pt.number,
  value: _pt.number.isRequired,
  "aria-describedby": _pt.string.isRequired,
  secondValue: _pt.number,
  getProgressColor: _pt.func,
  getSecondProgressColor: _pt.func,
  height: _pt.number
};

export { ProgressBar };
//# sourceMappingURL=ProgressBar.esm.js.map
