import { jsx } from '@emotion/core';
import { useState, useLayoutEffect } from 'react';
import _pt from 'prop-types';
import { visuallyHiddenCss } from '../../stylesheets/a11y.esm.js';

const triggerCss = theme => [visuallyHiddenCss, {
  position: `fixed`,
  zIndex: 9999999,
  top: theme.space[7],
  left: theme.space[7],
  padding: theme.space[5],
  borderRadius: theme.radii[2],
  background: theme.colors.white,
  color: theme.colors.blue[80],
  textDecoration: `none`,
  "&:focus": {
    width: `auto`,
    height: `auto`,
    clip: `auto`
  }
}];

const SKIP_TARGET_ID = `gatsby-skip-here`;
function SkipNavTrigger({
  children = `Skip to content`,
  targetId = SKIP_TARGET_ID
}) {
  const [hasAValidTarget, setHasAValidTarget] = useState(false);
  useLayoutEffect(() => {
    const target = document.getElementById(targetId);

    if (!!target !== hasAValidTarget) {
      setHasAValidTarget(!!target);
    }
  }); // If we've rendered the trigger, but there is no target available, we don't
  // want to show the trigger. Doing so would just be frustrating, since it
  // wouldn't skip anything.

  if (!hasAValidTarget) {
    return null;
  }

  return jsx("a", {
    href: `#${targetId}`,
    css: triggerCss
  }, children);
}
SkipNavTrigger.propTypes = {
  children: _pt.node,
  targetId: _pt.string
};
function SkipNavTarget({
  targetId = SKIP_TARGET_ID
}) {
  return jsx("div", {
    id: targetId,
    style: {
      contain: `none`
    }
  });
}
SkipNavTarget.propTypes = {
  targetId: _pt.string
};

export { SkipNavTarget, SkipNavTrigger };
//# sourceMappingURL=SkipNav.esm.js.map
