import { jsx } from '@emotion/core';
import { useTheme } from '../ThemeProvider/ThemeProvider.esm.js';

/** @jsx jsx */

const verticalCss = _theme => ({
  display: `block`,
  width: `unset`
});

const horizontalCss = _theme => ({
  display: `inline-block`,
  height: `unset`
});

function Spacer({
  size,
  direction = `vertical`,
  responsiveSize = {},
  responsiveDirection = {},
  className
}) {
  const theme = useTheme();
  const breakpoints = Object.keys(theme.mediaQueries);
  const responsiveStyles = {};

  for (const breakpoint of breakpoints) {
    const sizeForBreakpoint = responsiveSize[breakpoint] || size;
    const directionForBreakpoint = responsiveDirection[breakpoint] || direction;
    const sizePropertyForBreakpoint = directionForBreakpoint === `horizontal` ? `width` : `height`;
    const mediaQuery = theme.mediaQueries[breakpoint];
    responsiveStyles[mediaQuery] = [{
      [sizePropertyForBreakpoint]: theme.space[sizeForBreakpoint]
    }, directionForBreakpoint === `horizontal` ? horizontalCss() : verticalCss()];
  }

  const defaultSizeProperty = direction === `horizontal` ? `width` : `height`;
  return jsx("div", {
    css: [{
      [defaultSizeProperty]: theme.space[size]
    }, direction === `horizontal` ? horizontalCss() : verticalCss(), responsiveStyles],
    "aria-hidden": true,
    className: className
  });
}

export { Spacer };
//# sourceMappingURL=Spacer.esm.js.map
