import { jsx } from '@emotion/core';
import { useRef } from 'react';
import _pt from 'prop-types';
import { MdKeyboardArrowDown } from '../../node_modules/react-icons/md/index.esm.esm.js';
import { Button } from '../Button/Button.esm.js';
import { DropdownMenu, DropdownMenuButton, DropdownMenuPopover, DropdownMenuItemsLowLevel } from '../DropdownMenu/DropdownMenu.esm.js';
import { useIconButton } from '../IconButton/IconButton.esm.js';
import { positionRight } from '@reach/popover';

const baseCss = _theme => ({
  display: `inline-flex`,
  alignItems: `center`
});

const primaryButtonCss = _theme => ({
  borderTopRightRadius: 0,
  borderBottomRightRadius: 0,
  borderRightColor: `transparent`
});

const separatorCss = _theme => ({
  display: `inline-block`,
  width: 1,
  alignSelf: `stretch`
});

function SplitButton({
  buttonLabel,
  dropdownButtonLabel,
  children,
  variant,
  size,
  tone = `BRAND`,
  disabled,
  ...rest
}) {
  const containerRef = useRef(null);
  const iconButtonProps = useIconButton({
    icon: jsx(MdKeyboardArrowDown, null),
    children: dropdownButtonLabel,
    variant,
    size,
    tone
  });

  const finalIconButtonCss = theme => [iconButtonProps.css(theme), {
    borderTopLeftRadius: 0,
    borderBottomLeftRadius: 0,
    flexShrink: 0
  }];

  const finalSeparatorCss = theme => [separatorCss(), variant === `PRIMARY` && {
    background: `
        linear-gradient(${theme.colors.whiteFade[30]} 0%, ${theme.colors.whiteFade[30]} 100%),
        linear-gradient(${theme.tones[tone].dark} 0%, ${theme.tones[tone].dark} 100%)`
  }, variant === `SECONDARY` && {
    backgroundColor: `transparent`,
    borderTop: `1px solid ${theme.tones[tone].light}`,
    borderBottom: `1px solid ${theme.tones[tone].light}`
  }];

  const positionMenuPopover = (targetRect, popoverRect) => {
    return { ...positionRight(targetRect, popoverRect),
      minWidth: containerRef.current ? containerRef.current.clientWidth : `auto`
    };
  };

  return jsx("div", {
    ref: containerRef,
    css: baseCss
  }, jsx(Button, {
    variant: variant,
    size: size,
    tone: tone,
    disabled: disabled,
    css: primaryButtonCss,
    ...rest
  }, buttonLabel), jsx("span", {
    css: finalSeparatorCss,
    "aria-hidden": true
  }), jsx(DropdownMenu, null, jsx(DropdownMenuButton, { ...iconButtonProps,
    css: finalIconButtonCss,
    disabled: disabled
  }), jsx(DropdownMenuPopover, {
    position: positionMenuPopover
  }, jsx(DropdownMenuItemsLowLevel, {
    size: "AUTO"
  }, children))));
}
SplitButton.propTypes = {
  buttonLabel: _pt.node.isRequired,
  dropdownButtonLabel: _pt.node.isRequired,
  children: _pt.node
};

export { SplitButton };
//# sourceMappingURL=SplitButton.esm.js.map
