const reachUIDefaultStyles = {
  tabs: _theme => ({
    '[data-orientation="vertical"]': {
      display: `flex`
    }
  }),
  tabList: _theme => ({
    display: `flex`,
    '[aria-orientation="vertical"]': {
      flexDirection: `column`
    }
  }),
  tab: _theme => ({
    display: "inline-block",
    border: "none",
    background: "none",
    color: "inherit",
    font: "inherit",
    cursor: "pointer",
    WebkitAppearance: "none",
    MozAppearance: "none"
  })
};

const tabsCss = theme => [reachUIDefaultStyles.tabs(theme)];

const tabsListCss = theme => [reachUIDefaultStyles.tabList(theme), {
  display: `flex`,
  flexGrow: 1,
  flexShrink: 0,
  listStyleType: `none`,
  margin: 0,
  position: `relative`,
  overflowX: `auto`,
  WebkitOverflowScrolling: `touch`,
  "&::-webkit-scrollbar": {
    display: `none`
  },
  borderBottom: `1px solid ${theme.colors.blackFade[10]}`
}];

const tabCss = theme => [reachUIDefaultStyles.tab(theme), {
  flexShrink: 0,
  margin: 0,
  padding: 0,
  position: `relative`,
  "&:not(:last-of-type)": {
    marginRight: theme.space[5]
  }
}];

const tabButtonCss = theme => ({
  alignItems: `center`,
  display: `flex`,
  margin: 0,
  padding: `${theme.space[4]} ${theme.space[3]}`,
  position: `relative`,
  overflowY: `hidden`,
  color: theme.colors.grey[60],
  fontFamily: theme.fonts.system,
  fontSize: theme.fontSizes[2],
  background: `none`,
  border: `none`,
  cursor: `pointer`,
  "&:after": {
    borderTopLeftRadius: theme.radii[1],
    borderTopRightRadius: theme.radii[1],
    bottom: 0,
    content: `""`,
    left: 0,
    height: `4px`,
    position: `absolute`,
    transition: `transform ${theme.transitions.speed.default}`,
    width: `100%`,
    background: theme.colors.purple[30],
    transform: `translateY(100%)`
  },
  "&:hover": {
    "&:after": {
      transform: `translateY(40%)`
    }
  }
});

const tabButtonSelectedCss = theme => ({
  fontWeight: theme.fontWeights.bold,
  color: theme.colors.grey[70],
  "&:after": {
    background: theme.colors.purple[60],
    transform: `translateY(40%)`
  }
});

const tabsStyles = {
  tabs: tabsCss,
  tabList: tabsListCss,
  tab: tabCss,
  tabButton: tabButtonCss,
  tabButtonSelected: tabButtonSelectedCss
};

export { tabsStyles };
//# sourceMappingURL=Tabs.styles.esm.js.map
