import { jsx } from '@emotion/core';
import _pt from 'prop-types';
import { MdClose, MdDone } from '../../node_modules/react-icons/md/index.esm.esm.js';
import ThemeProvider from '../ThemeProvider/ThemeProvider.esm.js';
import Alert from '@reach/alert';

const MIN_HEIGHT = `3rem`;

const toastCss = theme => ({
  display: "flex",
  alignItems: "center",
  background: theme.colors.grey[90],
  borderLeft: `${theme.space[3]} solid ${theme.colors.green[50]}`,
  borderRadius: theme.radii[2],
  color: theme.colors.green[5],
  fontSize: theme.fontSizes[1],
  minHeight: MIN_HEIGHT,
  paddingLeft: theme.space[4]
});

const iconCss = theme => ({
  fontSize: theme.fontSizes[4]
});

const messageCss = theme => ({
  lineHeight: theme.lineHeights.solid,
  marginTop: 0,
  marginBottom: 0,
  marginRight: theme.space[2],
  marginLeft: theme.space[3]
});

const statusCss = theme => ({
  display: "flex",
  alignItems: "center",
  color: theme.colors.green[50]
});

const closeButtonCss = theme => ({
  display: "flex",
  alignItems: "center",
  background: "none",
  border: "none",
  color: theme.colors.grey[40],
  cursor: "pointer",
  height: MIN_HEIGHT,
  justifyContent: "center",
  width: MIN_HEIGHT,
  marginLeft: `auto`
});

function getToastColorByTone(theme, tone) {
  if (tone === `SUCCESS`) {
    return theme.colors.green[50];
  }

  throw new Error(`Unknown "tone" for Toast component: ${tone}`);
}

const ToastIconByTone = {
  SUCCESS: MdDone
};
function Toast({
  message,
  tone,
  closeButtonLabel,
  onClose,
  className,
  style
}) {
  const IconComponent = ToastIconByTone[tone];

  const finalToastCss = theme => [toastCss(theme), {
    borderLeftColor: getToastColorByTone(theme, tone)
  }];

  const finalStatusCss = theme => [statusCss(theme), {
    color: getToastColorByTone(theme, tone)
  }];

  return jsx(Alert, {
    css: finalToastCss,
    "data-testid": "toast",
    type: "polite",
    className: className,
    style: style
  }, jsx(ThemeProvider, null, jsx("span", {
    css: finalStatusCss
  }, jsx(IconComponent, {
    css: iconCss
  })), jsx("div", {
    css: messageCss
  }, message), jsx("button", {
    css: closeButtonCss,
    type: "button",
    onClick: onClose,
    "aria-label": closeButtonLabel
  }, jsx(MdClose, {
    css: iconCss
  }))));
}
Toast.propTypes = {
  message: _pt.node.isRequired,
  onClose: _pt.func.isRequired,
  closeButtonLabel: _pt.string.isRequired,
  className: _pt.string
};

export { Toast };
//# sourceMappingURL=Toast.esm.js.map
