import { jsx } from '@emotion/core';
import { useMemo } from 'react';
import _pt from 'prop-types';
import { animated as extendedAnimated, useSpring } from '../../node_modules/react-spring/web.esm.js';
import { Toast } from './Toast.esm.js';
import { ToastContext } from './ToastContext.esm.js';
import { useToastActions } from './hooks.esm.js';

const ToastConsumer = ToastContext.Consumer;

const containerCss = theme => ({
  alignItems: "center",
  bottom: 0,
  display: "flex",
  flexDirection: "column-reverse",
  left: "50%",
  position: "fixed",
  transform: "translate(-50%, 0)",
  width: "100%",
  zIndex: theme.zIndices.base,
  pointerEvents: `none`,
  paddingRight: theme.space[7],
  paddingLeft: theme.space[7]
});

const toastCss = theme => ({
  pointerEvents: `auto`,
  marginBottom: theme.space[1],
  "&:first-of-type": {
    borderBottomLeftRadius: 0,
    borderBottomRightRadius: 0,
    marginBottom: 0
  }
});

const AnimatedToast = extendedAnimated(Toast);

function ToastItem(props) {
  const styleProps = useSpring({
    from: {
      transform: `perspective(1000px) rotateX(90deg)`,
      transformOrigin: "bottom center"
    },
    to: {
      transform: `perspective(1000px) rotateX(0)`,
      transformOrigin: "bottom center"
    }
  });
  return jsx(AnimatedToast, {
    style: styleProps,
    ...props
  });
}

function ToastProvider({
  children,
  closeButtonLabel = `Close`
}) {
  const {
    toasts,
    showToast,
    removeToast
  } = useToastActions();
  const contextValue = useMemo(() => {
    return {
      showToast
    };
  }, [showToast]);
  return jsx(ToastContext.Provider, {
    value: contextValue
  }, children, jsx("div", {
    css: containerCss
  }, toasts.map((toast, index) => jsx(ToastItem, {
    key: `toast-${index}` // this is probably not the best, but we can't use symbol as key :(
    ,
    ...toast,
    onClose: () => removeToast(toast.id),
    closeButtonLabel: closeButtonLabel,
    css: toastCss
  }))));
}
ToastProvider.propTypes = {
  children: _pt.node.isRequired,
  closeButtonLabel: _pt.string
};

export { ToastConsumer, ToastProvider };
//# sourceMappingURL=ToastProvider.esm.js.map
