import { useCallback, useState, useRef, useEffect } from 'react';
import { useToastContext } from './ToastContext.esm.js';
import { DEFAULT_TONE, DEFAULT_TIMEOUT } from './constants.esm.js';

const useShowToast = () => {
  const {
    showToast
  } = useToastContext();
  return showToast;
};
const useShowSuccessToast = () => {
  const showToast = useShowToast();
  return useCallback((message, options = {}) => {
    showToast(message, { ...options,
      tone: `SUCCESS`
    });
  }, [showToast]);
};
const useToastActions = () => {
  const [toasts, setToasts] = useState([]);
  const timeoutsRef = useRef(new Map());
  const removeToast = useCallback(toastId => {
    setToasts(prevToasts => prevToasts.filter(({
      id
    }) => id !== toastId));
    window.clearTimeout(timeoutsRef.current.get(toastId));
    timeoutsRef.current.delete(toastId);
  }, []);
  const showToast = useCallback((message, {
    tone = DEFAULT_TONE,
    timeout = DEFAULT_TIMEOUT
  } = {}) => {
    const toastId = Symbol(`toast`);
    setToasts(prevToasts => [...prevToasts, {
      id: toastId,
      message,
      tone
    }]);

    if (timeout > 0) {
      const timeOutId = window.setTimeout(() => {
        removeToast(toastId);
      }, timeout);
      timeoutsRef.current.set(toastId, timeOutId);
    }
  }, []);
  useEffect(() => {
    // Clear all timeouts
    return () => {
      for (const timeout of timeoutsRef.current.values()) {
        window.clearTimeout(timeout);
      }
    };
  }, []);
  return {
    toasts,
    showToast,
    removeToast
  };
};

export { useShowSuccessToast, useShowToast, useToastActions };
//# sourceMappingURL=hooks.esm.js.map
