import { jsx } from '@emotion/core';
import { forwardRef, Fragment } from 'react';
import 'prop-types';
import { visuallyHiddenCss } from '../../stylesheets/a11y.esm.js';
import ToggleGutter, { ToggleGutterTagName, toggleGutterCheckedCss, toggleGutterFocusCss } from './ToggleGutter.esm.js';
import { toggleLabelCss } from './Toggle.styles.esm.js';

const BaseToggle = /*#__PURE__*/forwardRef(function BaseToggle({
  tone,
  className,
  style,
  ...rest
}, ref) {
  return jsx(Fragment, null, jsx("input", {
    ref: ref,
    type: "checkbox",
    value: "true",
    css: theme => [visuallyHiddenCss, {
      [`&:checked + ${ToggleGutterTagName}`]: toggleGutterCheckedCss(tone)(theme),
      [`&:focus + ${ToggleGutterTagName}`]: toggleGutterFocusCss(theme)
    }],
    ...rest
  }), jsx(ToggleGutter, {
    className: className,
    style: style
  }));
});
var ToggleCheckbox = /*#__PURE__*/forwardRef(function ToggleCheckbox({
  id,
  label,
  labelPosition = "end",
  className,
  style,
  ...rest
}, ref) {
  return jsx("label", {
    className: className,
    style: style,
    htmlFor: id,
    css: theme => [{
      display: `flex`,
      alignItems: `center`
    }, toggleLabelCss(theme)]
  }, jsx(BaseToggle, {
    ref: ref,
    id: id,
    ...rest,
    css: theme => labelPosition === `end` ? {
      marginRight: theme.space[3]
    } : {
      marginLeft: theme.space[3],
      order: 1
    }
  }), label);
});

export default ToggleCheckbox;
//# sourceMappingURL=ToggleCheckbox.esm.js.map
