import { Children, createElement, Fragment, cloneElement } from 'react';
import _pt from 'prop-types';
import { DisableReachStyleCheck } from '../../utils/helpers/DisableReachStyleCheck.esm.js';
import { useTransition, animated as extendedAnimated } from '../../node_modules/react-spring/web.esm.js';
import { useTooltip } from '@reach/tooltip';
import TooltipContent from './TooltipContent.esm.js';

const AnimatedTooltipContent = extendedAnimated(TooltipContent);
function Tooltip({
  children,
  id,
  label,
  position = "top",
  ...rest
}) {
  // COPIED FROM @reach/tooltip source:
  //
  // We need to pass some properties from the child into useTooltip
  // to make sure users can maintain control over the trigger's ref and events
  const child = Children.only(children);
  const [trigger, tooltipParams, isVisible] = useTooltip({
    id,
    onMouseEnter: child.props.onMouseEnter,
    onMouseMove: child.props.onMouseMove,
    onMouseLeave: child.props.onMouseLeave,
    onFocus: child.props.onFocus,
    onBlur: child.props.onBlur,
    onKeyDown: child.props.onKeyDown,
    onMouseDown: child.props.onMouseDown,
    ref: child.ref
  });
  const transitions = useTransition(isVisible ? tooltipParams : null, null, {
    // unit for the to-be-interpolated property is crucial for this to work
    // ref. https://github.com/pmndrs/react-spring/issues/779#issuecomment-520185113
    from: {
      opacity: 0,
      transform: "translate3d(0, 0px, 0)"
    },
    enter: {
      opacity: 1,
      transform: position === "top" ? "translate3d(0, -4px, 0)" : "translate3d(0, 4px, 0)"
    },
    leave: {
      opacity: 0,
      transform: "translate3d(0, 0, 0)"
    },
    config: {
      tension: 200,
      friction: 20
    }
  });
  return /*#__PURE__*/createElement(Fragment, null, /*#__PURE__*/cloneElement(child, trigger), transitions.map(({
    item: tooltip,
    props: transitionStyles,
    key
  }) => {
    if (!tooltip) {
      return null;
    }

    return /*#__PURE__*/createElement(AnimatedTooltipContent, {
      key: key,
      label: label,
      tooltipParams: tooltip,
      style: transitionStyles,
      position: position,
      ...rest
    });
  }), /*#__PURE__*/createElement(DisableReachStyleCheck, {
    reachComponent: "tooltip"
  }));
}
Tooltip.propTypes = {
  label: _pt.node.isRequired,
  children: _pt.node.isRequired
};

export default Tooltip;
//# sourceMappingURL=Tooltip.esm.js.map
