import { jsx } from '@emotion/core';
import { Fragment } from 'react';
import _pt from 'prop-types';
import { TooltipPopup } from '@reach/tooltip';
import TooltipPointer from './TooltipPointer.esm.js';
import { tooltipPosition } from './TooltipContent.helpers.esm.js';

const baseCss = theme => ({
  // defaults from @reach/tooltip
  zIndex: 1,
  pointerEvents: `none`,
  position: `absolute`,
  boxShadow: `2px 2px 10px hsla(0, 0%, 0%, 0.1)`,
  // gatsby-interface styles
  background: theme.colors.black,
  color: theme.colors.white,
  fontSize: theme.fontSizes[0],
  border: "none",
  borderRadius: theme.radii[2],
  padding: `${theme.space[3]} ${theme.space[4]}`,
  transformOrigin: "center",
  whiteSpace: "normal",
  maxWidth: "16rem",
  lineHeight: theme.lineHeights.dense
});

function TooltipContent({
  position = "top",
  label,
  tooltipParams,
  "aria-label": ariaLabel,
  style,
  ...rest
}) {
  return jsx(TooltipPopup, { ...tooltipParams,
    ...rest,
    label: jsx(Fragment, null, tooltipParams.triggerRect && jsx(TooltipPointer, {
      triggerRect: tooltipParams.triggerRect,
      position: position,
      style: style
    }), label),
    ariaLabel: ariaLabel,
    "aria-label": ariaLabel,
    css: baseCss,
    style: style,
    position: tooltipPosition[position]
  });
}
TooltipContent.propTypes = {
  label: _pt.node.isRequired
};

export default TooltipContent;
//# sourceMappingURL=TooltipContent.esm.js.map
