const ALIGN_TO_CSS_ALIGN = {
  center: `center`,
  right: `flex-end`,
  left: `flex-start`
};

function pickProperGap(gap, verticalGap) {
  return verticalGap ? verticalGap : gap;
}

function getGapVal(gap, t) {
  if (t && t.space[gap]) {
    return t.space[gap];
  }

  return gap;
}

function getClusterGapCalc(gap) {
  return `calc(${gap} / 2 * -1)`;
}

function getClusterItemGapCalc(gap) {
  return `calc(${gap} / 2)`;
}

function getMarginsCssValues(params) {
  const {
    gap,
    verticalGap,
    target = `cluster`,
    theme: t
  } = params;
  const calcGetter = target === `clusterItem` ? getClusterItemGapCalc : getClusterGapCalc;
  return {
    margin: calcGetter(getGapVal(gap, t)),
    marginBottom: calcGetter(getGapVal(pickProperGap(gap, verticalGap), t)),
    marginTop: calcGetter(getGapVal(pickProperGap(gap, verticalGap), t))
  };
}

function getClusterStyles(params) {
  const {
    gap = 0,
    verticalGap = 0,
    responsiveGaps = {},
    align = `left`,
    theme: t
  } = params || {};
  const clusterResponsiveGapsCss = {};
  const clusterItemResponsiveGapsCss = {};

  if (t && t.mediaQueries) {
    Object.entries(responsiveGaps).forEach(([breakpoint, gaps]) => {
      const mediaQuery = t.mediaQueries[breakpoint];
      const {
        gap,
        verticalGap
      } = gaps || {};

      if (mediaQuery && gap !== undefined && gap !== null) {
        clusterResponsiveGapsCss[mediaQuery] = getMarginsCssValues({
          gap,
          verticalGap,
          target: `cluster`,
          theme: t
        });
        clusterItemResponsiveGapsCss[mediaQuery] = getMarginsCssValues({
          gap,
          verticalGap,
          target: `clusterItem`,
          theme: t
        });
      }
    });
  }

  const clusterCss = {
    alignItems: ALIGN_TO_CSS_ALIGN[align || `justify`],
    display: `flex`,
    flexWrap: `wrap`,
    justifyContent: align ? ALIGN_TO_CSS_ALIGN[align] : `center`,
    ...getMarginsCssValues({
      gap,
      verticalGap,
      target: `cluster`,
      theme: t
    }),
    ...clusterResponsiveGapsCss
  };
  const clusterItemCss = { ...getMarginsCssValues({
      gap,
      verticalGap,
      target: `clusterItem`,
      theme: t
    }),
    ...clusterItemResponsiveGapsCss
  };
  return {
    clusterCss,
    clusterItemCss
  };
}

export { getClusterStyles };
//# sourceMappingURL=cluster.esm.js.map
