import { getErrorAriaLiveAttribute, getHintId, getErrorId } from '../utils/index.esm.js';

function useAriaFormField(fieldId, {
  required = false,
  hasError = false,
  hasHint = false,
  validationMode
}) {
  const hintId = getHintId(fieldId);
  const errorId = getErrorId(fieldId);
  const controlDescribedBy = [hasError && errorId, hasHint && hintId].filter(describedBy => describedBy).join(` `) || undefined;
  return {
    controlProps: {
      id: fieldId,
      "aria-describedby": controlDescribedBy,
      "aria-invalid": hasError,
      required
    },
    labelProps: {
      htmlFor: fieldId
    },
    hintProps: {
      id: hintId,
      hidden: !hasHint
    },
    errorProps: {
      id: errorId,
      hidden: !hasError,
      "aria-live": getErrorAriaLiveAttribute(validationMode)
    }
  };
}

export { useAriaFormField };
//# sourceMappingURL=useAriaFormField.esm.js.map
