import { jsx } from '@emotion/core';
import { forwardRef } from 'react';
import { useAriaFormField } from '../../form-skeletons/hooks/useAriaFormField.esm.js';
import { FormHint, FormError } from './styled-primitives/StyledFormElements.esm.js';
import { StyledCheckbox, StyledCheckboxLabel } from './styled-primitives/StyledCheckbox.esm.js';

/** @jsx jsx */

const baseCss = _theme => ({
  display: `flex`,
  alignItems: `baseline`
});

const checkboxContainerCss = theme => ({
  marginRight: theme.space[4]
});

const CheckboxFieldBlock = /*#__PURE__*/forwardRef(function CheckboxFieldBlock(props, ref) {
  const {
    id,
    label,
    labelSize,
    error,
    hint,
    className,
    validationMode,
    required,
    ...rest
  } = props;
  const fieldData = useAriaFormField(id, {
    required: required,
    hasError: !!error,
    hasHint: !!hint,
    validationMode
  });
  return jsx("div", {
    css: baseCss,
    className: className
  }, jsx("div", {
    css: checkboxContainerCss
  }, jsx(StyledCheckbox, {
    ref: ref,
    ...fieldData.controlProps,
    ...rest
  })), jsx("div", null, jsx(StyledCheckboxLabel, {
    required: fieldData.controlProps.required,
    labelSize: labelSize,
    ...fieldData.labelProps
  }, label), jsx(FormHint, { ...fieldData.hintProps
  }, hint), jsx(FormError, { ...fieldData.errorProps
  }, error)));
});

export { CheckboxFieldBlock };
//# sourceMappingURL=CheckboxFieldBlock.esm.js.map
