import { jsx } from '@emotion/core';
import { OptionsContainer } from './styled-primitives/StyledFormElements.esm.js';
import { getOptionLabelOffsetStyles } from '../styles/index.esm.js';
import { FormGroupFieldBlock } from './FormFieldBlock.esm.js';
import { StyledCheckbox, StyledCheckboxLabel } from './styled-primitives/StyledCheckbox.esm.js';

/** @jsx jsx */
const CheckboxGroupFieldBlock = props => {
  const {
    id,
    label,
    layout,
    optionsDirection,
    labelSize,
    options,
    error,
    hint,
    className,
    validationMode,
    value: fieldValue,
    required,
    maxHeight,
    utils,
    ...rest
  } = props;
  return jsx(FormGroupFieldBlock, {
    id: id,
    label: label,
    error: error,
    hint: hint,
    required: required,
    labelSize: labelSize,
    validationMode: validationMode,
    layout: layout,
    className: className
  }, ({
    getOptionControlProps,
    getOptionLabelProps
  }) => jsx(OptionsContainer, {
    maxHeight: maxHeight,
    optionsDirection: optionsDirection
  }, options.map(({
    value,
    label,
    ...restOption
  }) => jsx("div", {
    key: value,
    css: theme => [{
      display: `flex`,
      flexShrink: 0,
      marginBottom: theme.space[4]
    }, optionsDirection === `row` ? {
      marginRight: theme.space[6]
    } : {
      "&:last-of-type": {
        marginBottom: 0
      }
    }]
  }, jsx(StyledCheckbox, {
    value: value // Support uncontrolled field
    ,
    checked: fieldValue === undefined ? undefined : fieldValue.includes(value),
    ...getOptionControlProps(value),
    ...rest,
    ...restOption
  }), jsx(StyledCheckboxLabel, { ...getOptionLabelProps(value),
    css: getOptionLabelOffsetStyles(optionsDirection)
  }, label))), utils && utils));
};

export { CheckboxGroupFieldBlock };
//# sourceMappingURL=CheckboxGroupFieldBlock.esm.js.map
