import { jsx } from '@emotion/core';
import { useState } from 'react';
import { OptionsContainer } from './styled-primitives/StyledFormElements.esm.js';
import { getOptionLabelOffsetStyles } from '../styles/index.esm.js';
import { FormGroupFieldBlock } from './FormFieldBlock.esm.js';
import { StyledRadioButton, StyledRadioLabel } from './styled-primitives/StyledRadio.esm.js';

/** @jsx jsx */

const framedCss = theme => ({
  border: `2px solid ${theme.colors.white}`,
  borderRadius: theme.radii[3],
  margin: 0,
  width: `100%`,
  transition: `border .15s ease-in-out`,
  paddingTop: theme.space[4],
  paddingBottom: theme.space[4],
  paddingLeft: theme.space[4],
  paddingRight: theme.space[5]
});

const RadioButtonFieldBlock = props => {
  const {
    id,
    label,
    labelSize,
    error,
    hint,
    className,
    validationMode,
    value: fieldValue,
    options,
    layout,
    optionsDirection,
    variant,
    required,
    ...rest
  } = props;
  const [checkedOption, setCheckedOption] = useState(() => {
    if (fieldValue) {
      return fieldValue;
    }

    const defaultCheckedOption = options.find(({
      defaultChecked
    }) => defaultChecked);
    return defaultCheckedOption ? defaultCheckedOption.value : undefined;
  });
  return jsx(FormGroupFieldBlock, {
    id: id,
    label: label,
    error: error,
    hint: hint,
    required: required,
    labelSize: labelSize,
    validationMode: validationMode,
    layout: layout,
    className: className
  }, ({
    getOptionControlProps,
    getOptionLabelProps
  }) => jsx(OptionsContainer, {
    optionsDirection: optionsDirection
  }, options.map(({
    value,
    label,
    ...restOption
  }) => jsx("div", {
    key: value,
    onChange: () => setCheckedOption(value),
    css: theme => [{
      display: `flex`,
      flexShrink: 0,
      marginBottom: theme.space[4]
    }, variant === `framed` ? [framedCss(theme), value === checkedOption && {
      borderColor: theme.colors.purple[60]
    }] : [{
      marginBottom: theme.space[4]
    }, optionsDirection === `row` ? {
      marginRight: theme.space[6]
    } : {
      "&:last-of-type": {
        marginBottom: 0
      }
    }]]
  }, jsx(StyledRadioButton, {
    value: value // Support uncontrolled field
    ,
    checked: fieldValue === undefined ? undefined : fieldValue === value,
    ...getOptionControlProps(value),
    ...rest,
    ...restOption
  }), jsx(StyledRadioLabel, { ...getOptionLabelProps(value),
    css: getOptionLabelOffsetStyles(optionsDirection)
  }, label)))));
};

export { RadioButtonFieldBlock };
//# sourceMappingURL=RadioButtonFieldBlock.esm.js.map
