import { keyframes, jsx } from '@emotion/core';
import { Fragment } from 'react';
import _pt from 'prop-types';
import { MdError } from '../../../../node_modules/react-icons/md/index.esm.esm.js';

const auxillaryTextCss = theme => ({
  color: theme.colors.grey[50],
  fontSize: theme.fontSizes[0],
  lineHeight: theme.lineHeights.dense,
  position: `relative`,
  zIndex: 0
});

const errorEntry = keyframes`
    50% {
      opacity: .5;
    }
    to {
      opacity: 1;
    }
  `;
const errorIconEntry = keyframes`
    to {
      transform: translateY(-0.1em) scale(1) 
    }
  `;

const errorIconCss = theme => ({
  animation: `${errorIconEntry} .25s ease-out forwards`,
  height: `1em`,
  marginRight: theme.space[1],
  transform: `translateY(-0.1em) scale(0)`,
  verticalAlign: `middle`,
  width: `1em`
});

function FormError({
  children,
  ...rest
}) {
  const baseCss = theme => [auxillaryTextCss(theme), {
    animation: `${errorEntry} .25s ease forwards`,
    color: theme.colors.red[70],
    opacity: 0
  }, {
    marginTop: theme.space[2]
  }];

  return jsx("div", { ...rest,
    css: baseCss
  }, jsx(MdError, {
    css: errorIconCss
  }), children);
}
function FormHint(props) {
  const baseCss = theme => [auxillaryTextCss(theme), {
    marginTop: theme.space[2]
  }];

  return jsx("div", { ...props,
    css: baseCss
  });
}

const labelBaseCss = theme => ({
  color: theme.colors.grey[90],
  lineHeight: theme.lineHeights.dense,
  alignSelf: `baseline`,
  wordWrap: `break-word`,
  overflowWrap: `break-word`,
  hyphens: `auto`
});

const labelRequiredFlagCss = theme => ({
  color: theme.colors.grey[50],
  fontSize: theme.fontSizes[0],
  marginLeft: theme.space[1]
});

const labelSizeStyles = {
  L: theme => ({
    fontSize: theme.fontSizes[2]
  }),
  M: theme => ({
    fontSize: theme.fontSizes[1]
  }),
  S: theme => ({
    fontSize: theme.fontSizes[0]
  })
};

function getStyledFieldLabel(label, {
  labelSize = `M`,
  required
} = {}) {
  const finalLabel = required ? jsx(Fragment, null, label, " ", jsx("span", {
    css: labelRequiredFlagCss
  }, "(required)")) : label;

  const labelCss = theme => [labelBaseCss(theme), labelSizeStyles[labelSize](theme), {
    marginBottom: theme.space[2]
  }];

  return {
    finalLabel,
    labelCss
  };
}

function StyledLabel({
  children,
  required,
  labelSize,
  ...rest
}) {
  if (!children) {
    return null;
  }

  const {
    finalLabel,
    labelCss
  } = getStyledFieldLabel(children, {
    required,
    labelSize
  });
  return jsx("label", { ...rest,
    css: labelCss
  }, finalLabel);
}
StyledLabel.propTypes = {
  labelSize: _pt.oneOf(["L", "M", "S"]),
  required: _pt.bool
};
function FormLegend({
  children,
  required,
  labelSize,
  ...rest
}) {
  if (!children) {
    return null;
  }

  const {
    finalLabel,
    labelCss
  } = getStyledFieldLabel(children, {
    required,
    labelSize
  });

  const finalLabelCss = theme => [labelCss(theme), {
    display: `block`,
    padding: 0
  }];

  return jsx("legend", { ...rest,
    css: finalLabelCss
  }, finalLabel);
}
FormLegend.propTypes = {
  labelSize: _pt.oneOf(["L", "M", "S"]),
  required: _pt.bool
};
function FormFieldset(props) {
  return jsx("fieldset", { ...props,
    // CSS reset for <fieldset> based on https://thatemil.com/blog/2015/01/03/reset-your-fieldset/
    css: {
      border: 0,
      margin: 0,
      padding: `0.01em 0 0 0`,
      minWidth: 0
    }
  });
}

const horizontalOptionsCss = theme => ({
  display: `flex`,
  flexWrap: `wrap`,
  paddingTop: theme.space[3]
});

const verticalOptionsCss = theme => [{
  paddingTop: theme.space[3],
  paddingBottom: theme.space[3]
}];

const maxHeightCss = theme => [{
  border: `1px solid ${theme.colors.grey[30]}`,
  borderRadius: theme.radii[2],
  paddingTop: theme.space[5],
  paddingBottom: theme.space[5],
  paddingLeft: theme.space[5],
  paddingRight: theme.space[5],
  maxHeight: `150px`,
  overflow: `auto`
}];

function OptionsContainer({
  optionsDirection = `column`,
  maxHeight,
  ...rest
}) {
  const baseCss = theme => [optionsDirection === `row` ? horizontalOptionsCss(theme) : verticalOptionsCss(theme), maxHeight && maxHeightCss(theme), maxHeight && {
    maxHeight: maxHeight
  }];

  return jsx("div", {
    css: baseCss,
    ...rest
  });
}
OptionsContainer.propTypes = {
  maxHeight: _pt.string
};

export { FormError, FormFieldset, FormHint, FormLegend, OptionsContainer, StyledLabel };
//# sourceMappingURL=StyledFormElements.esm.js.map
