import { jsx } from '@emotion/core';
import { forwardRef } from 'react';
import _pt from 'prop-types';
import { baseInputCss } from '../../styles/index.esm.js';

const StyledSelect = /*#__PURE__*/forwardRef(function SelectFieldControl({
  options,
  ...rest
}, ref) {
  const baseCss = theme => [baseInputCss(theme), {
    padding: `0 ${theme.space[3]}`,
    backgroundImage: `url("data:image/svg+xml,%3Csvg stroke='currentColor' fill='currentColor' stroke-width='0' viewBox='0 0 24 24' height='1em' width='1em' xmlns='http://www.w3.org/2000/svg'%3E%3Cpath d='M16.59 8.59L12 13.17 7.41 8.59 6 10l6 6 6-6z'%3E%3C/path%3E%3C/svg%3E")`,
    backgroundRepeat: `no-repeat`,
    backgroundPosition: `right ${theme.space[3]} top 50%, 0 0`
  }];

  return jsx("select", {
    ref: ref,
    css: baseCss,
    ...rest
  }, options.map(renderOption));
});
StyledSelect.propTypes = {
  options: _pt.arrayOf(_pt.shape({
    value: _pt.string.isRequired,
    label: _pt.string.isRequired
  })).isRequired
};

function renderOption({
  label,
  value
}) {
  return jsx("option", {
    key: value,
    value: value
  }, label);
}

export { StyledSelect };
//# sourceMappingURL=StyledSelect.esm.js.map
