const ALIGN_TO_CSS_ALIGN = {
  stretch: `stretch`,
  center: `center`,
  right: `flex-end`,
  left: `flex-start`
};

function getGapVal(gap, t) {
  if (t && t.space[gap]) {
    return t.space[gap];
  }

  return gap;
}

function getStackStyles(params) {
  const {
    gap = 0,
    responsiveGap = {},
    align = `stretch`,
    direction = `column`,
    theme: t
  } = params || {};
  const isHorizontal = direction === `row`;
  let responsiveGapCss = {};

  if (t && t.mediaQueries) {
    responsiveGapCss = Object.entries(responsiveGap).reduce((acc, [breakpoint, gap]) => {
      const mediaQuery = t.mediaQueries[breakpoint];

      if (mediaQuery && gap !== undefined && gap !== null) {
        acc[mediaQuery] = {
          marginTop: !isHorizontal ? getGapVal(gap, t) : undefined,
          marginLeft: isHorizontal ? getGapVal(gap, t) : undefined
        };
      }

      return acc;
    }, {});
  }

  const stackCss = {
    display: `flex`,
    flexDirection: isHorizontal ? `row` : `column`,
    alignItems: !isHorizontal ? ALIGN_TO_CSS_ALIGN[align || `stretch`] : undefined,
    justifyContent: isHorizontal ? ALIGN_TO_CSS_ALIGN[align || `left`] : undefined,
    overflow: isHorizontal ? `auto` : undefined
  };
  const stackItemCss = {
    marginTop: !isHorizontal ? getGapVal(gap, t) : undefined,
    marginLeft: isHorizontal ? getGapVal(gap, t) : undefined,
    flexShrink: isHorizontal ? 0 : undefined,
    "&:first-child": {
      marginTop: !isHorizontal ? 0 : undefined,
      marginLeft: isHorizontal ? 0 : undefined
    },
    ...responsiveGapCss
  };
  return {
    stackCss,
    stackItemCss
  };
}

export { getStackStyles };
//# sourceMappingURL=stack.esm.js.map
