import { radii, shadows, fontWeights, fontSizes, lineHeights, letterSpacings, transition } from 'gatsby-design-tokens';
import colors from './colors.esm.js';
import fonts from './fonts.esm.js';
import zIndices from './zIndices.esm.js';
import space from './space.esm.js';
import breakpoints, { breakpointsList } from './breakpoints.esm.js';
import tones from './tones.esm.js';

const themeColors = colors;
/**
 * Tones
 */

const themeTones = tones;
/**
 * Font families
 */

const themeFonts = fonts;
/**
 * Font weights
 */

const themeFontWeights = fontWeights;
/**
 * Font sizes
 */

const themeFontSizes = fontSizes;
/**
 * Line heights
 */

const themeLineHeights = lineHeights;
/**
 * Letter spacings
 */

const themeLetterSpacings = letterSpacings;
/**
 * Space
 */

const themeSpace = space;
/**
 * Radii
 */

const themeRadii = radii;
/**
 * Shadows
 */

const themeShadows = shadows;
/**
 * Z indices
 */

const themeZIndices = zIndices;
/**
 * Breakpoints
 */

const themeBreakpoints = breakpointsList;
/**
 * Media breakpoints
 */

const themeMediaBreakpoints = breakpoints;
/**
 * Media queries
 */

const themeMediaQueries = Object.entries(breakpoints).reduce((memo, [breakpoint, widthInPx]) => {
  return { ...memo,
    [breakpoint]: `@media (min-width: ${widthInPx}px)`
  };
}, {});
/**
 * Transitions
 */

const themeTransitions = transition;
/**
 * Cards
 */

const themeCardStyles = {
  frame: {
    background: colors.primaryBackground,
    borderRadius: radii[2],
    boxShadow: shadows.raised
  },
  space: {
    DEFAULT: {
      paddingTop: space[6],
      paddingBottom: space[5],
      paddingLeft: space[7],
      paddingRight: space[3]
    },
    M: {
      paddingTop: space[5],
      paddingBottom: space[5],
      paddingLeft: space[9],
      paddingRight: space[9]
    },
    L: {
      paddingTop: space[7],
      paddingBottom: space[8],
      paddingLeft: space[9],
      paddingRight: space[9]
    }
  }
};
const defaultTheme = {
  colors: themeColors,
  tones: themeTones,
  fonts: themeFonts,
  fontWeights: themeFontWeights,
  fontSizes: themeFontSizes,
  lineHeights: themeLineHeights,
  letterSpacings: themeLetterSpacings,
  space: themeSpace,
  radii: themeRadii,
  shadows: themeShadows,
  zIndices: themeZIndices,
  breakpoints: themeBreakpoints,
  mediaBreakpoints: themeMediaBreakpoints,
  mediaQueries: themeMediaQueries,
  transitions: themeTransitions,
  cardStyles: themeCardStyles
};
function getTheme() {
  return defaultTheme;
}

export { getTheme };
//# sourceMappingURL=index.esm.js.map
